pub unsafe extern "C" fn de265_decode_data(
arg1: *mut de265_decoder_context,
data: *const c_void,
length: c_int,
) -> TypeExpand description
Push more data into the decoder, must be raw h265. All complete images in the data will be decoded, hence, do not push too much data at once to prevent image buffer overflows. The end of a picture can only be detected when the succeeding start-code is read from the data. If you want to flush the data and force decoding of the data so far (e.g. at the end of a file), call de265_decode_data() with ‘length’ zero.
NOTE: This method is deprecated and will be removed in a future version. You should use “de265_push_data” or “de265_push_NAL” and “de265_decode” instead.