pub unsafe extern "C" fn de265_init() -> TypeExpand description
Static library initialization. Must be paired with de265_free(). Initialization is optional, since it will be done implicitly in de265_new_decoder(). Return value is false if initialization failed. Only call de265_free() when initialization was successful. Multiple calls to ‘init’ are allowed, but must be matched with an equal number of ‘free’ calls.