pub unsafe extern "C" fn de265_flush_data(
arg1: *mut de265_decoder_context,
) -> TypeExpand description
Indicate the end-of-stream. All data pending at the decoder input will be pushed into the decoder and the decoded picture queue will be completely emptied.