pub unsafe extern "C" fn de265_push_data(
arg1: *mut de265_decoder_context,
data: *const c_void,
length: c_int,
pts: de265_PTS,
user_data: *mut c_void,
) -> TypeExpand description
Push more data into the decoder, must be a raw h265 bytestream with startcodes. The PTS is assigned to all NALs whose start-code 0x000001 is contained in the data. The bytestream must contain all stuffing-bytes. This function only pushes data into the decoder, nothing will be decoded.